@@ -1,5 +1,5 @@
  /* The smooth Class Library
-  * Copyright (C) 1998-2014 Robert Kausch <robert.kausch@gmx.net>
+  * Copyright (C) 1998-2020 Robert Kausch <robert.kausch@gmx.net>
   *
   * This library is free software; you can redistribute it and/or
   * modify it under the terms of "The Artistic License, Version 2.0".
@@ -50,6 +50,9 @@ namespace smooth
 			private:
 				X11::Display	*display;
 			public:
+				static Int	 Initialize();
+ 				static Int	 Free();
+ 
 						 ScreenXLib();
 						~ScreenXLib();
 
